Module: ScreenshotFreeAPI
- Defined in:
- lib/screenshotfreeapi.rb,
lib/screenshotfreeapi/client.rb,
lib/screenshotfreeapi/errors.rb,
lib/screenshotfreeapi/version.rb,
lib/screenshotfreeapi/webhooks.rb,
lib/screenshotfreeapi/http_client.rb,
lib/screenshotfreeapi/resources/auth.rb,
lib/screenshotfreeapi/resources/jobs.rb,
lib/screenshotfreeapi/resources/billing.rb,
lib/screenshotfreeapi/resources/monitors.rb,
lib/screenshotfreeapi/resources/workspaces.rb,
lib/screenshotfreeapi/resources/screenshots.rb,
lib/screenshotfreeapi/resources/integrations.rb
Defined Under Namespace
Modules: Resources, Webhooks Classes: AuthenticationError, Client, ForbiddenError, HttpClient, JobFailedError, JobTimeoutError, NotFoundError, PaymentRequiredError, QuotaExceededError, RateLimitError, ScreenshotFreeAPIError, ValidationError
Constant Summary collapse
- VERSION =
"1.0.0"
Class Method Summary collapse
-
.new(api_key:, **opts) ⇒ ScreenshotFreeAPI::Client
Convenience constructor — creates a Client without needing to reference the full class path.
Class Method Details
.new(api_key:, **opts) ⇒ ScreenshotFreeAPI::Client
Convenience constructor — creates a Client without needing to reference the full class path.
44 45 46 |
# File 'lib/screenshotfreeapi.rb', line 44 def self.new(api_key:, **opts) Client.new(api_key: api_key, **opts) end |